#!/usr/bin/env python
"""Test basic NetCDF generation."""

import os
from datetime import datetime

import numpy as np


def get_nc_schema_database(fields=None):
    """Get a version of the NetCDF schema that mimics the nc script."""
    from aosstower import schema

    if fields is None:
        fields = schema.met_vars
    mini_database = {k: schema.database_dict[k] for k in fields}
    return mini_database


def test_nc_basic1(tmpdir):
    """Test basic usage of the NetCDF generation."""
    from netCDF4 import Dataset

    from aosstower.level_b1.nc import create_giant_netcdf
    from aosstower.tests.utils import get_cached_level_00

    input_files = list(get_cached_level_00(num_files=2))
    nc_out = tmpdir.join("test.nc")
    create_giant_netcdf(
        input_files,
        str(nc_out),
        True,
        None,
        start=datetime(2020, 1, 2, 0, 0, 0),
        interval_width="1T",
        database=get_nc_schema_database(),
    )
    assert os.path.isfile(nc_out)
    with Dataset(nc_out, "r") as nc:
        sflux = nc["solar_flux"][:]
        assert np.count_nonzero(sflux.mask) == 2
